@@ -91,7 +91,7 @@ class Row():
         if len(chain) > 1:
             self.initial_comment_id = None
 
-        comments = models.CommentTree(reddit=submission_tree.reddit)
+        comments = models.CommentTree(reddit=submission_tree.reddit, verbosity=verbosity)
         if deepest_comment:
             for comment in self.submission.comments:
                 comments.add_missing_replies(comment)
@@ -102,7 +102,6 @@ class Row():
                 comment = submission_tree.reddit.comment(self.comment_id)
             comments.add_missing_replies(comment)
         comments.get_missing_replies = False
-        comments.verbose = (verbosity > 1)
         comments.prune(side_thread)
         if deepest_comment:
             comment = comments.deepest_node.walk_up_tree(limit=3)[-1]
